
# Type: chemical to disease or phenotypic feature association_object




URI: [biolink:chemical_to_disease_or_phenotypic_feature_association_object](https://w3id.org/biolink/vocab/chemical_to_disease_or_phenotypic_feature_association_object)


## Domain and Range

[ChemicalToDiseaseOrPhenotypicFeatureAssociation](ChemicalToDiseaseOrPhenotypicFeatureAssociation.md) ->  <sub>REQ</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [ChemicalToDiseaseOrPhenotypicFeatureAssociation](ChemicalToDiseaseOrPhenotypicFeatureAssociation.md)
